==> openjdk-src-11.0.2.u7-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_yo_BJ.java <==
/*
 * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_yo_BJ extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "Diami ti Awon Or\u00edl\u025b\u0301\u00e8de Arabu" },
            { "aoa", "Wansa ti Or\u00edl\u025b\u0301\u00e8de \u00c0ng\u00f3l\u00e0" },
            { "aud", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de \u00c1str\u00e0l\u00ec\u00e1" },
            { "bhd", "Dina ti Or\u00edl\u025b\u0301\u00e8de B\u00e1r\u00e1n\u00ec" },
            { "bif", "Faransi ti Or\u00edl\u025b\u0301\u00e8de B\u00f9\u00f9r\u00fand\u00ec" },
            { "bwp", "Pula ti Or\u00edl\u025b\u0301\u00e8de B\u0254\u0300t\u00ecs\u00faw\u00e1n\u00e0" },
            { "cad", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de K\u00e1n\u00e1d\u00e0" },
            { "cdf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de K\u00f3ng\u00f2" },
            { "chf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Siwisi" },
            { "cny", "Reminibi ti Or\u00edl\u025b\u0301\u00e8de sh\u00e1\u00edn\u00e0" },
            { "cve", "Kabofediano ti Or\u00edl\u025b\u0301\u00e8de Esuodo" },
            { "djf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Dibouti" },
            { "dzd", "Dina ti Or\u00edl\u025b\u0301\u00e8de \u00c0l\u00f9g\u00e8r\u00ed\u00e1n\u00ec" },
            { "egp", "p\u0254\u0254n ti Or\u00edl\u025b\u0301\u00e8de Egipiti" },
            { "ern", "Nakifa ti Or\u00edl\u025b\u0301\u00e8de Eriteriani" },
            { "etb", "Biri ti Or\u00edl\u025b\u0301\u00e8de Eutopia" },
            { "gbp", "P\u0254\u0254n ti Or\u00edl\u025b\u0301\u00e8de B\u00edr\u00edt\u00eds\u00ec" },
            { "ghc", "shidi ti Or\u00edl\u025b\u0301\u00e8de Gana" },
            { "gmd", "Dalasi ti Or\u00edl\u025b\u0301\u00e8de Gamibia" },
            { "gns", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Gini" },
            { "inr", "Rupi ti Or\u00edl\u025b\u0301\u00e8de Indina" },
            { "jpy", "Yeni ti Or\u00edl\u025b\u0301\u00e8de Japani" },
            { "kes", "shiili ti Or\u00edl\u025b\u0301\u00e8de Kenya" },
            { "kmf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de shomoriani" },
            { "lrd", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Liberia" },
            { "lsl", "Loti ti Or\u00edl\u025b\u0301\u00e8de Lesoto" },
            { "lyd", "Dina ti Or\u00edl\u025b\u0301\u00e8de Libiya" },
            { "mad", "Dirami ti Or\u00edl\u025b\u0301\u00e8de Moroko" },
            { "mga", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Malagasi" },
            { "mro", "Ouguiya ti Or\u00edl\u025b\u0301\u00e8de Maritania (1973\u20132017)" },
            { "mru", "Ouguiya ti Or\u00edl\u025b\u0301\u00e8de Maritania" },
            { "mur", "Rupi ti Or\u00edl\u025b\u0301\u00e8de Maritiusi" },
            { "mwk", "Kasha ti Or\u00edl\u025b\u0301\u00e8de Malawi" },
            { "mzm", "Metika ti Or\u00edl\u025b\u0301\u00e8de Mosamibiki" },
            { "nad", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Namibia" },
            { "ngn", "Naira ti Or\u00edl\u025b\u0301\u00e8de N\u00e0\u00ecj\u00edr\u00ed\u00e0" },
            { "rwf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Ruwanda" },
            { "sar", "Riya ti Or\u00edl\u025b\u0301\u00e8de Saudi" },
            { "scr", "Rupi ti Or\u00edl\u025b\u0301\u00e8de Sayiselesi" },
            { "sdg", "Dina ti Or\u00edl\u025b\u0301\u00e8de Sudani" },
            { "sdp", "P\u0254\u0254un ti Or\u00edl\u025b\u0301\u00e8de Sudani" },
            { "shp", "P\u0254\u0254un ti Or\u00edl\u025b\u0301\u00e8de \u0323Elena" },
            { "sos", "Sile ti Or\u00edl\u025b\u0301\u00e8de Somali" },
            { "std", "Dobira ti Or\u00edl\u025b\u0301\u00e8de Sao tome Ati Pirisipe (1977\u20132017)" },
            { "stn", "Dobira ti Or\u00edl\u025b\u0301\u00e8de Sao tome Ati Pirisipe" },
            { "tnd", "Dina ti Or\u00edl\u025b\u0301\u00e8de Tunisia" },
            { "tzs", "Sile ti Or\u00edl\u025b\u0301\u00e8de Tansania" },
            { "ugx", "Siile ti Or\u00edl\u025b\u0301\u00e8de Uganda" },
            { "usd", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Amerika" },
            { "xaf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de BEKA" },
            { "xof", "Faransi ti Or\u00edl\u025b\u0301\u00e8de BIKEAO" },
            { "zar", "Randi ti Or\u00edl\u025b\u0301\u00e8de Ariwa Afirika" },
            { "zmk", "Kawasha ti Or\u00edl\u025b\u0301\u00e8de Saabia (1968\u20132012)" },
            { "zmw", "Kawasha ti Or\u00edl\u025b\u0301\u00e8de Saabia" },
            { "zwd", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Siibabuwe" },
        };
        return data;
    }
}

==> openjdk-src-14.0.1.u7-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_yo_BJ.java <==
/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_yo_BJ extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "Diami ti Awon Or\u00edl\u025b\u0301\u00e8de Arabu" },
            { "aoa", "Wansa ti Or\u00edl\u025b\u0301\u00e8de \u00c0ng\u00f3l\u00e0" },
            { "aud", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de \u00c1str\u00e0l\u00ec\u00e1" },
            { "bhd", "Dina ti Or\u00edl\u025b\u0301\u00e8de B\u00e1r\u00e1n\u00ec" },
            { "bif", "Faransi ti Or\u00edl\u025b\u0301\u00e8de B\u00f9\u00f9r\u00fand\u00ec" },
            { "brl", "Ow\u00f3 ti Or\u00edl\u025b\u0300-\u00e8d\u00e8 Brazil" },
            { "bwp", "Pula ti Or\u00edl\u025b\u0301\u00e8de B\u0254\u0300t\u00ecs\u00faw\u00e1n\u00e0" },
            { "cad", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de K\u00e1n\u00e1d\u00e0" },
            { "cdf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de K\u00f3ng\u00f2" },
            { "chf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Siwisi" },
            { "cny", "Reminibi ti Or\u00edl\u025b\u0301\u00e8de sh\u00e1\u00edn\u00e0" },
            { "cve", "Kabofediano ti Or\u00edl\u025b\u0301\u00e8de Esuodo" },
            { "djf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Dibouti" },
            { "dzd", "Dina ti Or\u00edl\u025b\u0301\u00e8de \u00c0l\u00f9g\u00e8r\u00ed\u00e1n\u00ec" },
            { "egp", "p\u0254\u0254n ti Or\u00edl\u025b\u0301\u00e8de Egipiti" },
            { "ern", "Nakifa ti Or\u00edl\u025b\u0301\u00e8de Eriteriani" },
            { "etb", "Biri ti Or\u00edl\u025b\u0301\u00e8de Eutopia" },
            { "gbp", "P\u0254\u0301n-\u00f9n ti Oril\u025b\u0300-\u00e8d\u00e8 G\u025b\u0300\u025b\u0301s\u00ec" },
            { "ghc", "shidi ti Or\u00edl\u025b\u0301\u00e8de Gana" },
            { "gmd", "Dalasi ti Or\u00edl\u025b\u0301\u00e8de Gamibia" },
            { "gns", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Gini" },
            { "inr", "Rupi ti Or\u00edl\u025b\u0301\u00e8de Indina" },
            { "jpy", "Yeni ti Or\u00edl\u025b\u0301\u00e8de Japani" },
            { "kes", "shiili ti Or\u00edl\u025b\u0301\u00e8de Kenya" },
            { "kmf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de shomoriani" },
            { "lrd", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Liberia" },
            { "lsl", "Loti ti Or\u00edl\u025b\u0301\u00e8de Lesoto" },
            { "lyd", "Dina ti Or\u00edl\u025b\u0301\u00e8de Libiya" },
            { "mad", "Dirami ti Or\u00edl\u025b\u0301\u00e8de Moroko" },
            { "mga", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Malagasi" },
            { "mro", "Ouguiya ti Or\u00edl\u025b\u0301\u00e8de Maritania (1973\u20132017)" },
            { "mru", "Ouguiya ti Or\u00edl\u025b\u0301\u00e8de Maritania" },
            { "mur", "Rupi ti Or\u00edl\u025b\u0301\u00e8de Maritiusi" },
            { "mwk", "Kasha ti Or\u00edl\u025b\u0301\u00e8de Malawi" },
            { "mzm", "Metika ti Or\u00edl\u025b\u0301\u00e8de Mosamibiki" },
            { "nad", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Namibia" },
            { "ngn", "N\u00e1\u00ecr\u00e0 ti Or\u00edl\u025b\u0300-\u00e8d\u00e8 N\u00e0\u00ecj\u00edr\u00ed\u00e0" },
            { "rub", "Ow\u00f3 ruble ti il\u025b\u0300 R\u0254\u0301sh\u00ed\u00e0" },
            { "rwf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Ruwanda" },
            { "sar", "Riya ti Or\u00edl\u025b\u0301\u00e8de Saudi" },
            { "scr", "Rupi ti Or\u00edl\u025b\u0301\u00e8de Sayiselesi" },
            { "sdg", "Dina ti Or\u00edl\u025b\u0301\u00e8de Sudani" },
            { "sdp", "P\u0254\u0254un ti Or\u00edl\u025b\u0301\u00e8de Sudani" },
            { "shp", "P\u0254\u0254un ti Or\u00edl\u025b\u0301\u00e8de \u0323Elena" },
            { "sos", "Sile ti Or\u00edl\u025b\u0301\u00e8de Somali" },
            { "std", "Dobira ti Or\u00edl\u025b\u0301\u00e8de Sao tome Ati Pirisipe (1977\u20132017)" },
            { "stn", "Dobira ti Or\u00edl\u025b\u0301\u00e8de Sao tome Ati Pirisipe" },
            { "tnd", "Dina ti Or\u00edl\u025b\u0301\u00e8de Tunisia" },
            { "tzs", "Sile ti Or\u00edl\u025b\u0301\u00e8de Tansania" },
            { "ugx", "Siile ti Or\u00edl\u025b\u0301\u00e8de Uganda" },
            { "usd", "D\u0254\u0301l\u00e0" },
            { "xaf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de BEKA" },
            { "xof", "Faransi ti Or\u00edl\u025b\u0301\u00e8de BIKEAO" },
            { "xxx", "ow\u00f3n\u00edn\u00e1 \u00e0\u00ecm\u0254\u0300" },
            { "zar", "Randi ti Or\u00edl\u025b\u0301\u00e8de Ariwa Afirika" },
            { "zmk", "Kawasha ti Or\u00edl\u025b\u0301\u00e8de Saabia (1968\u20132012)" },
            { "zmw", "Kawasha ti Or\u00edl\u025b\u0301\u00e8de Saabia" },
            { "zwd", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Siibabuwe" },
        };
        return data;
    }
}
